@@ -6,12 +6,15 @@ no traceback if the metadata disk cannot be found.
 import pytest
 
 from tests.integration_tests.instances import IntegrationInstance
+from tests.integration_tests.integration_settings import PLATFORM
 from tests.integration_tests.util import verify_clean_log
 
 
 # With some datasource hacking, we can run this on a NoCloud instance
-@pytest.mark.lxd_container
-@pytest.mark.lxd_vm
+@pytest.mark.skipif(
+    PLATFORM not in ["lxd_container", "lxd_vm"],
+    reason="Tested behavior is emulated using NoCloud",
+)
 def test_datasource_rbx_no_stacktrace(client: IntegrationInstance):
     client.write_to_file(
         "/etc/cloud/cloud.cfg.d/90_dpkg.cfg",
