@@ -29,3 +29,5 @@ def test_gpg_no_tty(client: IntegrationInstance):
         "Imported key 'E4D304DF' from keyserver 'keyserver.ubuntu.com'",
     ]
     verify_ordered_items_in_text(to_verify, log)
+    result = client.execute("systemctl status cloud-config.service")
+    assert "CGroup" not in result.stdout
