@@ -3,6 +3,7 @@ import re
 import pytest
 
 from tests.integration_tests.clouds import IntegrationCloud
+from tests.integration_tests.integration_settings import PLATFORM
 from tests.integration_tests.util import verify_clean_log
 
 USER_DATA = """\
@@ -16,7 +17,7 @@ drivers:
 
 
 @pytest.mark.adhoc  # Expensive instance type
-@pytest.mark.oci
+@pytest.mark.skipif(PLATFORM != "oci", reason="Test is OCI specific")
 def test_ubuntu_drivers_installed(session_cloud: IntegrationCloud):
     with session_cloud.launch(
         launch_kwargs={"instance_type": "VM.GPU2.1"}, user_data=USER_DATA
