@@ -11,10 +11,11 @@ from textwrap import dedent
 
 import pytest
 
+from cloudinit.atomic_helper import b64e
 from cloudinit.cmd import query
 from cloudinit.helpers import Paths
 from cloudinit.sources import REDACT_SENSITIVE_VALUE
-from cloudinit.util import b64e, write_file
+from cloudinit.util import write_file
 from tests.unittests.helpers import mock
 
 M_PATH = "cloudinit.cmd.query."
@@ -34,7 +35,6 @@ def setup_mocks(mocker):
 
 @mock.patch(M_PATH + "addLogHandlerCLI", lambda *args: "")
 class TestQuery:
-
     Args = namedtuple(
         "Args",
         "debug dump_all format instance_data list_keys user_data vendor_data"
@@ -326,7 +326,7 @@ class TestQuery:
             with mock.patch("os.getuid", return_value=0):
                 assert 0 == query.handle_args("anyname", args)
         expected = (
-            '{\n "my-var": "it worked",\n '
+            '{\n "combined_cloud_config": null,\n "my-var": "it worked",\n '
             '"userdata": "instance_link_ud",\n '
             '"vendordata": "instance_link_vd"\n}\n'
         )
@@ -358,7 +358,7 @@ class TestQuery:
                 m_getuid.return_value = 0
                 assert 0 == query.handle_args("anyname", args)
         expected = (
-            '{\n "my-var": "it worked",\n '
+            '{\n "combined_cloud_config": null,\n "my-var": "it worked",\n '
             '"userdata": "ud",\n "vendordata": "vd"\n}\n'
         )
         out, _err = capsys.readouterr()
@@ -382,7 +382,9 @@ class TestQuery:
             m_getuid.return_value = 100
             assert 0 == query.handle_args("anyname", args)
         expected = (
-            '{\n "my-var": "it worked",\n "userdata": "<%s> file:ud",\n'
+            '{\n "combined_cloud_config": "<redacted for non-root user> file:'
+            '/run/cloud-init/combined-cloud-config.json",\n "my-var":'
+            ' "it worked",\n "userdata": "<%s> file:ud",\n'
             ' "vendordata": "<%s> file:vd"\n}\n'
             % (REDACT_SENSITIVE_VALUE, REDACT_SENSITIVE_VALUE)
         )
@@ -460,6 +462,7 @@ class TestQuery:
         expected = dedent(
             """\
             {
+             "combined_cloud_config": "<redacted for non-root user> %s",
              "top": "gun",
              "userdata": "<redacted for non-root user> file:ud",
              "v1": {
@@ -473,6 +476,7 @@ class TestQuery:
              "vendordata": "<redacted for non-root user> file:vd"
             }
         """
+            % "file:/run/cloud-init/combined-cloud-config.json"
         )
         args = self.Args(
             debug=False,
@@ -499,7 +503,10 @@ class TestQuery:
             '{"v1": {"v1_1": "val1.1"}, "v2": {"v2_2": "val2.2"},'
             ' "top": "gun"}'
         )
-        expected = "top\nuserdata\nv1\nv1_1\nv2\nv2_2\nvendordata\n"
+        expected = (
+            "combined_cloud_config\ntop\nuserdata\nv1\nv1_1\nv2\nv2_2\n"
+            "vendordata\n"
+        )
         args = self.Args(
             debug=False,
             dump_all=False,
@@ -523,7 +530,7 @@ class TestQuery:
         instance_data = tmpdir.join("instance-data")
         instance_data.write(
             '{"v1": {"v1_1": "val1.1", "v1_2": "val1.2"}, "v2":'
-            + ' {"v2_2": "val2.2"}, "top": "gun"}'
+            ' {"v2_2": "val2.2"}, "top": "gun"}'
         )
         expected = "v1_1\nv1_2\n"
         args = self.Args(
@@ -549,7 +556,7 @@ class TestQuery:
         instance_data = tmpdir.join("instance-data")
         instance_data.write(
             '{"v1": {"v1_1": "val1.1", "v1_2": "val1.2"}, "v2": '
-            + '{"v2_2": "val2.2"}, "top": "gun"}'
+            '{"v2_2": "val2.2"}, "top": "gun"}'
         )
         expected_error = "--list-keys provided but 'top' is not a dict"
         args = self.Args(
