@@ -55,9 +55,7 @@ class GoodTests(CiTestCase):
         Emulates a system that is already registered. Ensure it gets
         a non-ProcessExecution error from is_registered()
         """
-        self.handle(
-            self.name, self.config, self.cloud_init, self.log, self.args
-        )
+        self.handle(self.name, self.config, self.cloud_init, self.args)
         self.assertEqual(m_sman_cli.call_count, 1)
         self.assertIn("System is already registered", self.logs.getvalue())
 
@@ -70,9 +68,7 @@ class GoodTests(CiTestCase):
             " 12345678-abde-abcde-1234-1234567890abc"
         )
         m_sman_cli.side_effect = [subp.ProcessExecutionError, (reg, "bar")]
-        self.handle(
-            self.name, self.config, self.cloud_init, self.log, self.args
-        )
+        self.handle(self.name, self.config, self.cloud_init, self.args)
         self.assertIn(mock.call(["identity"]), m_sman_cli.call_args_list)
         self.assertIn(
             mock.call(
@@ -131,9 +127,7 @@ class GoodTests(CiTestCase):
             ("Repo ID: repo2\nRepo ID: repo3\nRepo ID: repo4", ""),
             ("", ""),
         ]
-        self.handle(
-            self.name, self.config_full, self.cloud_init, self.log, self.args
-        )
+        self.handle(self.name, self.config_full, self.cloud_init, self.args)
         self.assertEqual(m_sman_cli.call_count, 9)
         for call in call_lists:
             self.assertIn(mock.call(call), m_sman_cli.call_args_list)
@@ -213,7 +207,6 @@ class TestBadInput(CiTestCase):
             self.name,
             self.config_no_password,
             self.cloud_init,
-            self.log,
             self.args,
         )
         self.assertEqual(m_sman_cli.call_count, 0)
@@ -221,9 +214,7 @@ class TestBadInput(CiTestCase):
     def test_no_org(self, m_sman_cli):
         """Attempt to register without the org key/value."""
         m_sman_cli.side_effect = [subp.ProcessExecutionError]
-        self.handle(
-            self.name, self.config_no_key, self.cloud_init, self.log, self.args
-        )
+        self.handle(self.name, self.config_no_key, self.cloud_init, self.args)
         m_sman_cli.assert_called_with(["identity"])
         self.assertEqual(m_sman_cli.call_count, 1)
         self.assert_logged_warnings(
@@ -245,7 +236,6 @@ class TestBadInput(CiTestCase):
             self.name,
             self.config_service,
             self.cloud_init,
-            self.log,
             self.args,
         )
         self.assertEqual(m_sman_cli.call_count, 1)
@@ -268,7 +258,6 @@ class TestBadInput(CiTestCase):
             self.name,
             self.config_badpool,
             self.cloud_init,
-            self.log,
             self.args,
         )
         self.assertEqual(m_sman_cli.call_count, 2)
@@ -291,7 +280,6 @@ class TestBadInput(CiTestCase):
             self.name,
             self.config_badrepo,
             self.cloud_init,
-            self.log,
             self.args,
         )
         self.assertEqual(m_sman_cli.call_count, 2)
@@ -311,9 +299,7 @@ class TestBadInput(CiTestCase):
             subp.ProcessExecutionError,
             (self.reg, "bar"),
         ]
-        self.handle(
-            self.name, self.config_badkey, self.cloud_init, self.log, self.args
-        )
+        self.handle(self.name, self.config_badkey, self.cloud_init, self.args)
         self.assertEqual(m_sman_cli.call_count, 1)
         self.assert_logged_warnings(
             (
