@@ -16,6 +16,7 @@ from pathlib import Path
 from typing import ClassVar, List, Union
 from unittest import mock
 from unittest.util import strclass
+from urllib.parse import urlsplit, urlunsplit
 
 import responses
 
@@ -173,7 +174,7 @@ class CiTestCase(TestCase):
             )
         if pass_through:
             return _real_subp(*args, **kwargs)
-        raise Exception(
+        raise RuntimeError(
             "called subp. set self.allowed_subp=True to allow\n subp(%s)"
             % ", ".join(
                 [str(repr(a)) for a in args]
@@ -373,12 +374,43 @@ class FilesystemMockingTestCase(ResourceUsingTestCase):
             self.patched_funcs.close()
 
 
+class CiRequestsMock(responses.RequestsMock):
+    def assert_call_count(self, url: str, count: int) -> bool:
+        """Focal and older have a version of responses which does
+        not carry this attribute. This can be removed when focal
+        is no longer supported.
+        """
+        if hasattr(super(), "_ensure_url_default_path"):
+            return super().assert_call_count(url, count)
+
+        def _ensure_url_default_path(url):
+            if isinstance(url, str):
+                url_parts = list(urlsplit(url))
+                if url_parts[2] == "":
+                    url_parts[2] = "/"
+                    url = urlunsplit(url_parts)
+            return url
+
+        call_count = len(
+            [
+                1
+                for call in self.calls
+                if call.request.url == _ensure_url_default_path(url)
+            ]
+        )
+        if call_count == count:
+            return True
+        else:
+            raise AssertionError(
+                f"Expected URL '{url}' to be called {count} times. "
+                f"Called {call_count} times."
+            )
+
+
 class ResponsesTestCase(CiTestCase):
     def setUp(self):
         super().setUp()
-        self.responses = responses.RequestsMock(
-            assert_all_requests_are_fired=False
-        )
+        self.responses = CiRequestsMock(assert_all_requests_are_fired=False)
         self.responses.start()
 
     def tearDown(self):
@@ -491,9 +523,23 @@ try:
     import jsonschema
 
     assert jsonschema  # avoid pyflakes error F401: import unused
+    _jsonschema_version = tuple(
+        int(part) for part in jsonschema.__version__.split(".")  # type: ignore
+    )
     _missing_jsonschema_dep = False
 except ImportError:
     _missing_jsonschema_dep = True
+    _jsonschema_version = (0, 0, 0)
+
+
+def skipUnlessJsonSchemaVersionGreaterThan(version=(0, 0, 0)):
+    return skipIf(
+        _jsonschema_version <= version,
+        reason=(
+            f"python3-jsonschema {_jsonschema_version} not greater than"
+            f" {version}"
+        ),
+    )
 
 
 def skipUnlessJsonSchema():
