@@ -11,6 +11,7 @@ import pytest
 import requests
 
 from cloudinit import url_helper
+from cloudinit.sources.azure import errors
 from cloudinit.sources.helpers import azure as azure_helper
 from cloudinit.sources.helpers.azure import WALinuxAgentShim as wa_shim
 from cloudinit.util import load_file
@@ -105,15 +106,6 @@ HEALTH_REPORT_DESCRIPTION_TRIM_LEN = 512
 MOCKPATH = "cloudinit.sources.helpers.azure."
 
 
-@pytest.fixture
-def mock_dmi_read_dmi_data():
-    with mock.patch(
-        MOCKPATH + "dmi.read_dmi_data",
-        autospec=True,
-    ) as m:
-        yield m
-
-
 @pytest.fixture
 def mock_readurl():
     with mock.patch(MOCKPATH + "url_helper.readurl", autospec=True) as m:
@@ -196,28 +188,6 @@ class TestGoalStateParsing(CiTestCase):
         goal_state = self._get_goal_state(instance_id=instance_id)
         self.assertEqual(instance_id, goal_state.instance_id)
 
-    def test_instance_id_byte_swap(self):
-        """Return true when previous_iid is byteswapped current_iid"""
-        previous_iid = "D0DF4C54-4ECB-4A4B-9954-5BDF3ED5C3B8"
-        current_iid = "544CDFD0-CB4E-4B4A-9954-5BDF3ED5C3B8"
-        self.assertTrue(
-            azure_helper.is_byte_swapped(previous_iid, current_iid)
-        )
-
-    def test_instance_id_no_byte_swap_same_instance_id(self):
-        previous_iid = "D0DF4C54-4ECB-4A4B-9954-5BDF3ED5C3B8"
-        current_iid = "D0DF4C54-4ECB-4A4B-9954-5BDF3ED5C3B8"
-        self.assertFalse(
-            azure_helper.is_byte_swapped(previous_iid, current_iid)
-        )
-
-    def test_instance_id_no_byte_swap_diff_instance_id(self):
-        previous_iid = "D0DF4C54-4ECB-4A4B-9954-5BDF3ED5C3B8"
-        current_iid = "G0DF4C54-4ECB-4A4B-9954-5BDF3ED5C3B8"
-        self.assertFalse(
-            azure_helper.is_byte_swapped(previous_iid, current_iid)
-        )
-
     def test_certificates_xml_parsed_and_fetched_correctly(self):
         m_azure_endpoint_client = mock.MagicMock()
         certificates_url = "TestCertificatesUrl"
@@ -1380,7 +1350,10 @@ class TestGetMetadataGoalStateXMLAndReportFailureToFabric(CiTestCase):
         )
 
     def test_success_calls_clean_up(self):
-        azure_helper.report_failure_to_fabric(endpoint="test_endpoint")
+        error = errors.ReportableError(reason="test")
+        azure_helper.report_failure_to_fabric(
+            endpoint="test_endpoint", error=error
+        )
         self.assertEqual(1, self.m_shim.return_value.clean_up.call_count)
 
     def test_failure_in_shim_report_failure_propagates_exc_and_calls_clean_up(
@@ -1393,66 +1366,35 @@ class TestGetMetadataGoalStateXMLAndReportFailureToFabric(CiTestCase):
             SentinelException,
             azure_helper.report_failure_to_fabric,
             "test_endpoint",
+            errors.ReportableError(reason="test"),
         )
         self.assertEqual(1, self.m_shim.return_value.clean_up.call_count)
 
     def test_report_failure_to_fabric_calls_shim_report_failure(
         self,
     ):
-        azure_helper.report_failure_to_fabric(endpoint="test_endpoint")
+        error = errors.ReportableError(reason="test")
+
+        azure_helper.report_failure_to_fabric(
+            endpoint="test_endpoint",
+            error=error,
+        )
         # default err message description should be shown to the user
         # if an empty description is passed in
         self.m_shim.return_value.register_with_azure_and_report_failure.assert_called_once_with(  # noqa: E501
-            description=(
-                azure_helper.DEFAULT_REPORT_FAILURE_USER_VISIBLE_MESSAGE
-            )
+            description=error.as_encoded_report(),
         )
 
     def test_instantiates_shim_with_kwargs(self):
         azure_helper.report_failure_to_fabric(
             endpoint="test_endpoint",
+            error=errors.ReportableError(reason="test"),
         )
         self.m_shim.assert_called_once_with(
             endpoint="test_endpoint",
         )
 
 
-class TestChassisAssetTag:
-    def test_true_azure_cloud(self, caplog, mock_dmi_read_dmi_data):
-        mock_dmi_read_dmi_data.return_value = (
-            azure_helper.ChassisAssetTag.AZURE_CLOUD.value
-        )
-
-        asset_tag = azure_helper.ChassisAssetTag.query_system()
-
-        assert asset_tag == azure_helper.ChassisAssetTag.AZURE_CLOUD
-        assert caplog.record_tuples == [
-            (
-                "cloudinit.sources.helpers.azure",
-                10,
-                "Azure chassis asset tag: "
-                "'7783-7084-3265-9085-8269-3286-77' (AZURE_CLOUD)",
-            )
-        ]
-
-    @pytest.mark.parametrize("tag", [None, "", "notazure"])
-    def test_false_on_nonazure_chassis(
-        self, caplog, mock_dmi_read_dmi_data, tag
-    ):
-        mock_dmi_read_dmi_data.return_value = tag
-
-        asset_tag = azure_helper.ChassisAssetTag.query_system()
-
-        assert asset_tag is None
-        assert caplog.record_tuples == [
-            (
-                "cloudinit.sources.helpers.azure",
-                10,
-                "Non-Azure chassis asset tag: %r" % tag,
-            )
-        ]
-
-
 class TestOvfEnvXml:
     @pytest.mark.parametrize(
         "ovf,expected",
